# Generated by Django 3.2.11 on 2022-05-28 00:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_omise', '0004_auto_20220523_0847'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='charge',
            options={'permissions': [('issue_refund', 'Can issue refunds')]},
        ),
    ]
