base_charge_response = """{"object":"charge","id":"chrg_test_5s1kvbjga85m8a8rwu2","location":"/charges/chrg_test_5s1kvbjga85m8a8rwu2","amount":100000,"net":96094,"fee":3650,"fee_vat":256,"interest":0,"interest_vat":0,"funding_amount":100000,"refunded_amount":0,"transaction_fees":{"fee_flat":"0.0","fee_rate":"3.65","vat_rate":"7.0"},"platform_fee":{"fixed":null,"amount":null,"percentage":null},"currency":"THB","funding_currency":"THB","ip":null,"refunds":{"object":"list","data":[],"limit":20,"offset":0,"total":0,"location":"/charges/chrg_test_5s1kvbjga85m8a8rwu2/refunds","order":"chronological","from":"1970-01-01T00:00:00Z","to":"2022-06-05T11:09:02Z"},"link":null,"description":"Charge for order 3947","metadata":{},"card":{"object":"card","id":"card_test_5s1jzgw7oda499o8k0y","livemode":false,"location":"/customers/cust_test_5s1jz157366mu6wr0ng/cards/card_test_5s1jzgw7oda499o8k0y","deleted":false,"street1":null,"street2":null,"city":"Bangkok","state":null,"phone_number":null,"postal_code":"10320","country":"us","financing":"credit","bank":"JPMORGAN CHASE BANK N.A.","brand":"Visa","fingerprint":"7jGh9VWw5Dvm/8Zrh9wY/e3VXhdWyg8k8xD1+8sHGhU=","first_digits":null,"last_digits":"4242","name":"JOHN DOE","expiration_month":6,"expiration_year":2024,"security_code_check":true,"tokenization_method":null,"created_at":"2022-06-05T09:38:32Z"},"source":null,"schedule":null,"customer":"cust_test_5s1jz157366mu6wr0ng","dispute":null,"transaction":"trxn_test_5s1kvbn1zds49714yo4","failure_code":null,"failure_message":null,"status":"successful","authorize_uri":"https://api.omise.co/payments/paym_test_5s1kvbjhn176xynlizh/authorize","return_uri":"http://www.example.com/orders/3947/complete","created_at":"2022-06-05T11:09:01Z","paid_at":"2022-06-05T11:09:01Z","expires_at":"2022-06-12T11:09:01Z","expired_at":null,"reversed_at":null,"zero_interest_installments":false,"branch":null,"terminal":null,"device":null,"authorized":true,"capturable":false,"capture":true,"disputable":true,"livemode":false,"refundable":true,"reversed":false,"reversible":false,"voided":false,"paid":true,"expired":false}"""

base_charge_with_metadata_response = """{"object":"charge","id":"chrg_test_5s1kvbjga85m8a8rwu2","location":"/charges/chrg_test_5s1kvbjga85m8a8rwu2","amount":100000,"net":96094,"fee":3650,"fee_vat":256,"interest":0,"interest_vat":0,"funding_amount":100000,"refunded_amount":0,"transaction_fees":{"fee_flat":"0.0","fee_rate":"3.65","vat_rate":"7.0"},"platform_fee":{"fixed":null,"amount":null,"percentage":null},"currency":"THB","funding_currency":"THB","ip":null,"refunds":{"object":"list","data":[],"limit":20,"offset":0,"total":0,"location":"/charges/chrg_test_5s1kvbjga85m8a8rwu2/refunds","order":"chronological","from":"1970-01-01T00:00:00Z","to":"2022-06-05T11:09:02Z"},"link":null,"description":"Charge for order 3947","metadata":{"data": "data"},"card":{"object":"card","id":"card_test_5s1jzgw7oda499o8k0y","livemode":false,"location":"/customers/cust_test_5s1jz157366mu6wr0ng/cards/card_test_5s1jzgw7oda499o8k0y","deleted":false,"street1":null,"street2":null,"city":"Bangkok","state":null,"phone_number":null,"postal_code":"10320","country":"us","financing":"credit","bank":"JPMORGAN CHASE BANK N.A.","brand":"Visa","fingerprint":"7jGh9VWw5Dvm/8Zrh9wY/e3VXhdWyg8k8xD1+8sHGhU=","first_digits":null,"last_digits":"4242","name":"JOHN DOE","expiration_month":6,"expiration_year":2024,"security_code_check":true,"tokenization_method":null,"created_at":"2022-06-05T09:38:32Z"},"source":null,"schedule":null,"customer":"cust_test_5s1jz157366mu6wr0ng","dispute":null,"transaction":"trxn_test_5s1kvbn1zds49714yo4","failure_code":null,"failure_message":null,"status":"successful","authorize_uri":"https://api.omise.co/payments/paym_test_5s1kvbjhn176xynlizh/authorize","return_uri":"http://www.example.com/orders/3947/complete","created_at":"2022-06-05T11:09:01Z","paid_at":"2022-06-05T11:09:01Z","expires_at":"2022-06-12T11:09:01Z","expired_at":null,"reversed_at":null,"zero_interest_installments":false,"branch":null,"terminal":null,"device":null,"authorized":true,"capturable":false,"capture":true,"disputable":true,"livemode":false,"refundable":true,"reversed":false,"reversible":false,"voided":false,"paid":true,"expired":false}"""

base_charge_jpy = """{"object":"charge","id":"chrg_test_5s1l8lhaafl9d4aaa7o","location":"/charges/chrg_test_5s1l8lhaafl9d4aaa7o","amount":100000,"net":2427668,"fee":92211,"fee_vat":6455,"interest":0,"interest_vat":0,"funding_amount":2526334,"refunded_amount":0,"transaction_fees":{"fee_flat":"0.0","fee_rate":"3.65","vat_rate":"7.0"},"platform_fee":{"fixed":null,"amount":null,"percentage":null},"currency":"JPY","funding_currency":"THB","ip":null,"refunds":{"object":"list","data":[],"limit":20,"offset":0,"total":0,"location":"/charges/chrg_test_5s1l8lhaafl9d4aaa7o/refunds","order":"chronological","from":"1970-01-01T00:00:00Z","to":"2022-06-05T11:46:45Z"},"link":null,"description":"Charge for order 3947","metadata":{},"card":{"object":"card","id":"card_test_5s1jzgw7oda499o8k0y","livemode":false,"location":"/customers/cust_test_5s1jz157366mu6wr0ng/cards/card_test_5s1jzgw7oda499o8k0y","deleted":false,"street1":null,"street2":null,"city":"Bangkok","state":null,"phone_number":null,"postal_code":"10320","country":"us","financing":"credit","bank":"JPMORGAN CHASE BANK N.A.","brand":"Visa","fingerprint":"7jGh9VWw5Dvm/8Zrh9wY/e3VXhdWyg8k8xD1+8sHGhU=","first_digits":null,"last_digits":"4242","name":"JOHN DOE","expiration_month":6,"expiration_year":2024,"security_code_check":true,"tokenization_method":null,"created_at":"2022-06-05T09:38:32Z"},"source":null,"schedule":null,"customer":"cust_test_5s1jz157366mu6wr0ng","dispute":null,"transaction":"trxn_test_5s1l8lly1hoehgljhva","failure_code":null,"failure_message":null,"status":"successful","authorize_uri":"https://api.omise.co/payments/paym_test_5s1l8lhds9x6b5dw6k0/authorize","return_uri":"http://www.example.com/orders/3947/complete","created_at":"2022-06-05T11:46:44Z","paid_at":"2022-06-05T11:46:44Z","expires_at":"2022-06-12T11:46:43Z","expired_at":null,"reversed_at":null,"zero_interest_installments":false,"branch":null,"terminal":null,"device":null,"authorized":true,"capturable":false,"capture":true,"disputable":true,"livemode":false,"refundable":true,"reversed":false,"reversible":false,"voided":false,"paid":true,"expired":false}"""

partially_refunded_response = """{"object":"charge","id":"test_charge_id","location":"/charges/test_charge_id","amount":100000,"net":96094,"fee":3650,"fee_vat":256,"interest":0,"interest_vat":0,"funding_amount":100000,"refunded_amount":50000,"transaction_fees":{"fee_flat":"0.0","fee_rate":"3.65","vat_rate":"7.0"},"platform_fee":{"fixed":null,"amount":null,"percentage":null},"currency":"THB","funding_currency":"THB","ip":null,"refunds":{"object":"list","data":[{"object":"refund","id":"rfnd_test_5s1kvj7i16l6lrqco9c","location":"/charges/test_charge_id/refunds/rfnd_test_5s1kvj7i16l6lrqco9c","livemode":false,"voided":false,"currency":"THB","amount":50000,"metadata":{},"charge":"test_charge_id","terminal":null,"transaction":"trxn_test_5s1kvj7lln9kh4v8k3d","status":"closed","funding_amount":50000,"funding_currency":"THB","created_at":"2022-06-05T11:09:37Z"}],"limit":20,"offset":0,"total":1,"location":"/charges/test_charge_id/refunds","order":"chronological","from":"1970-01-01T00:00:00Z","to":"2022-06-05T11:09:45Z"},"link":null,"description":"Charge for order 3947","metadata":{},"card":{"object":"card","id":"card_test_5s1jzgw7oda499o8k0y","livemode":false,"location":"/customers/cust_test_5s1jz157366mu6wr0ng/cards/card_test_5s1jzgw7oda499o8k0y","deleted":false,"street1":null,"street2":null,"city":"Bangkok","state":null,"phone_number":null,"postal_code":"10320","country":"us","financing":"credit","bank":"JPMORGAN CHASE BANK N.A.","brand":"Visa","fingerprint":"7jGh9VWw5Dvm/8Zrh9wY/e3VXhdWyg8k8xD1+8sHGhU=","first_digits":null,"last_digits":"4242","name":"JOHN DOE","expiration_month":6,"expiration_year":2024,"security_code_check":true,"tokenization_method":null,"created_at":"2022-06-05T09:38:32Z"},"source":null,"schedule":null,"customer":"cust_test_5s1jz157366mu6wr0ng","dispute":null,"transaction":"trxn_test_5s1kvbn1zds49714yo4","failure_code":null,"failure_message":null,"status":"successful","authorize_uri":"https://api.omise.co/payments/paym_test_5s1kvbjhn176xynlizh/authorize","return_uri":"http://www.example.com/orders/3947/complete","created_at":"2022-06-05T11:09:01Z","paid_at":"2022-06-05T11:09:01Z","expires_at":"2022-06-12T11:09:01Z","expired_at":null,"reversed_at":null,"zero_interest_installments":false,"branch":null,"terminal":null,"device":null,"authorized":true,"capturable":false,"capture":true,"disputable":true,"livemode":false,"refundable":true,"reversed":false,"reversible":false,"voided":false,"paid":true,"expired":false}"""

fully_refunded_response = """{"object":"charge","id":"test_charge_id","location":"/charges/test_charge_id","amount":100000,"net":96094,"fee":3650,"fee_vat":256,"interest":0,"interest_vat":0,"funding_amount":100000,"refunded_amount":100000,"transaction_fees":{"fee_flat":"0.0","fee_rate":"3.65","vat_rate":"7.0"},"platform_fee":{"fixed":null,"amount":null,"percentage":null},"currency":"THB","funding_currency":"THB","ip":null,"refunds":{"object":"list","data":[{"object":"refund","id":"rfnd_test_5s1kvj7i16l6lrqco9c","location":"/charges/test_charge_id/refunds/rfnd_test_5s1kvj7i16l6lrqco9c","livemode":false,"voided":false,"currency":"THB","amount":50000,"metadata":{},"charge":"test_charge_id","terminal":null,"transaction":"trxn_test_5s1kvj7lln9kh4v8k3d","status":"closed","funding_amount":50000,"funding_currency":"THB","created_at":"2022-06-05T11:09:37Z"},{"object":"refund","id":"rfnd_test_5s1kvp13mtlmgaftih6","location":"/charges/test_charge_id/refunds/rfnd_test_5s1kvp13mtlmgaftih6","livemode":false,"voided":false,"currency":"THB","amount":50000,"metadata":{},"charge":"test_charge_id","terminal":null,"transaction":"trxn_test_5s1kvp16x977nh39ivs","status":"closed","funding_amount":50000,"funding_currency":"THB","created_at":"2022-06-05T11:10:05Z"}],"limit":20,"offset":0,"total":2,"location":"/charges/test_charge_id/refunds","order":"chronological","from":"1970-01-01T00:00:00Z","to":"2022-06-05T11:10:14Z"},"link":null,"description":"Charge for order 3947","metadata":{},"card":{"object":"card","id":"card_test_5s1jzgw7oda499o8k0y","livemode":false,"location":"/customers/cust_test_5s1jz157366mu6wr0ng/cards/card_test_5s1jzgw7oda499o8k0y","deleted":false,"street1":null,"street2":null,"city":"Bangkok","state":null,"phone_number":null,"postal_code":"10320","country":"us","financing":"credit","bank":"JPMORGAN CHASE BANK N.A.","brand":"Visa","fingerprint":"7jGh9VWw5Dvm/8Zrh9wY/e3VXhdWyg8k8xD1+8sHGhU=","first_digits":null,"last_digits":"4242","name":"JOHN DOE","expiration_month":6,"expiration_year":2024,"security_code_check":true,"tokenization_method":null,"created_at":"2022-06-05T09:38:32Z"},"source":null,"schedule":null,"customer":"cust_test_5s1jz157366mu6wr0ng","dispute":null,"transaction":"trxn_test_5s1kvbn1zds49714yo4","failure_code":null,"failure_message":null,"status":"successful","authorize_uri":"https://api.omise.co/payments/paym_test_5s1kvbjhn176xynlizh/authorize","return_uri":"http://www.example.com/orders/3947/complete","created_at":"2022-06-05T11:09:01Z","paid_at":"2022-06-05T11:09:01Z","expires_at":"2022-06-12T11:09:01Z","expired_at":null,"reversed_at":null,"zero_interest_installments":false,"branch":null,"terminal":null,"device":null,"authorized":true,"capturable":false,"capture":true,"disputable":false,"livemode":false,"refundable":false,"reversed":false,"reversible":false,"voided":false,"paid":true,"expired":false}"""

charge_with_schedule_response = """{"object":"charge","id":"test_charge_id","location":"/charges/test_charge_id","amount":200000,"net":192189,"fee":7300,"fee_vat":511,"interest":0,"interest_vat":0,"funding_amount":200000,"refunded_amount":0,"transaction_fees":{"fee_flat":"0.0","fee_rate":"3.65","vat_rate":"7.0"},"platform_fee":{"fixed":null,"amount":null,"percentage":null},"currency":"THB","funding_currency":"THB","ip":null,"refunds":{"object":"list","data":[],"limit":20,"offset":0,"total":0,"location":"/charges/test_charge_id/refunds","order":"chronological","from":"1970-01-01T00:00:00Z","to":"2022-06-17T11:24:08Z"},"link":null,"description":null,"metadata":{},"card":{"object":"card","id":"card_test_5rwur2pj0oa7blxex9x","livemode":false,"location":"/customers/test_customer_id/cards/card_test_5rwur2pj0oa7blxex9x","deleted":false,"street1":null,"street2":null,"city":null,"state":null,"phone_number":null,"postal_code":null,"country":"us","financing":"credit","bank":"JPMORGAN CHASE BANK N.A.","brand":"Visa","fingerprint":"oOHg2QCA2wKkUXIDCVLVspG+u7n/xv9ogrvZ9xtZhcQ=","first_digits":null,"last_digits":"1111","name":"James","expiration_month":10,"expiration_year":2030,"security_code_check":true,"tokenization_method":null,"created_at":"2022-05-24T09:11:32Z"},"source":null,"schedule":"schd_test_5s67suxlifb0r6vzqar","customer":"test_customer_id","dispute":null,"transaction":"trxn_test_5s67sv1zzy51fun0vn9","failure_code":null,"failure_message":null,"status":"successful","authorize_uri":null,"return_uri":null,"created_at":"2022-06-17T07:40:39Z","paid_at":"2022-06-17T07:40:39Z","expires_at":"2022-06-24T07:40:39Z","expired_at":null,"reversed_at":null,"zero_interest_installments":false,"branch":null,"terminal":null,"device":null,"authorized":true,"capturable":false,"capture":true,"disputable":true,"livemode":false,"refundable":true,"reversed":false,"reversible":false,"voided":false,"paid":true,"expired":false}"""
